colibri_stateless library
Public entry point for Colibri Stateless Dart bindings.
Prefer: import 'package:colibri_stateless/colibri_stateless.dart';
Classes
- Colibri
- High-level Colibri client for proofed RPC calls.
- ColibriStorage
- Storage abstraction used by the native verifier/prover for caching.
- DataRequest
- A pending data request emitted by the native library during proof/verify.
- MemoryStorage
- Simple in-memory ColibriStorage implementation.
Enums
- MethodType
- Classification of how an RPC method is supported by Colibri.
- PrivacyMode
- Pragmatic Adaptive Privacy mode.
- ProverMode
- Proof generation mode controlling how proofs are built and verified.
Exceptions / Errors
- ColibriError
- Base exception type for all Colibri Dart errors.
- HTTPError
- Thrown when HTTP transport fails for a data request.
- ProofError
- Thrown when proof creation fails.
- RevertError
-
Thrown when an
eth_call(or similar EVM execution) ran to completion but reverted. The verifier has fully verified the revert -- this is a legitimate outcome of EVM execution, not a transport or proof error. - RPCError
- Thrown when an RPC call returns a JSON-RPC error.
- VerificationError
- Thrown when proof verification fails.