colibri library
Public entry point for Colibri Dart bindings.
Consider using package:colibri_stateless/colibri_stateless.dart for
consistency with the package name and for canonical API documentation.
Classes
- Colibri
- High-level Colibri client for proofed RPC calls.
- ColibriStorage
- Storage abstraction used by the native verifier/prover for caching.
- DataRequest
- A pending data request emitted by the native library during proof/verify.
- MemoryStorage
- Simple in-memory ColibriStorage implementation.
Enums
- MethodType
- Classification of how an RPC method is supported by Colibri.
- PrivacyMode
- Pragmatic Adaptive Privacy mode.
Exceptions / Errors
- ColibriError
- Base exception type for all Colibri Dart errors.
- HTTPError
- Thrown when HTTP transport fails for a data request.
- ProofError
- Thrown when proof creation fails.
- RPCError
- Thrown when an RPC call returns a JSON-RPC error.
- VerificationError
- Thrown when proof verification fails.